Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Manifest ¶
func Manifest() spicestarter.Manifest
Manifest returns exact compatibility and activation metadata.
This package function is required by the Spice starter-manifest protocol.
Types ¶
type TextInspection ¶
type TextInspection struct {
Bytes int `json:"bytes"`
Runes int `json:"runes"`
Words int `json:"words"`
Lines int `json:"lines"`
SHA256 string `json:"sha256"`
}
TextInspection is a deterministic, immutable summary of one UTF-8 string.
func NewTextInspection ¶
func NewTextInspection(text string) TextInspection
NewTextInspection constructs the canonical summary for text.
type TextInspectionRequest ¶
type TextInspectionRequest struct {
Text string `json:"text"`
}
TextInspectionRequest is the strict model-visible input for text.inspect.
type TextInspector ¶
type TextInspector struct {
// contains filtered or unexported fields
}
TextInspector implements the deterministic read-only text.inspect tool.
func NewTextInspector ¶
func NewTextInspector() (*TextInspector, error)
NewTextInspector constructs the extension tool and validates its public definition.
func (*TextInspector) Definition ¶
func (inspector *TextInspector) Definition() tool.Definition
Definition returns a defensive copy of the model-visible contract.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package autoconfigure contributes text.inspect only through an explicit blank import.
|
Package autoconfigure contributes text.inspect only through an explicit blank import. |
|
internal
|
|
|
qualitygate
command
|
|
Click to show internal directories.
Click to hide internal directories.